@@ -1,16 +1,18 @@
 # pylint: skip-file
-from sqlalchemy.ext.asyncio import AsyncSession
-
 from .connectionmanager import connections
 from .connection import Connection
+from .connectionmanager import get
+from .connectionmanager import session
 from .connectionmanager import ConnectionManager
 from .declarative import declarative_base
+from .queryrunner import QueryRunner
 from .repository import Repository
 
 
 __all__ = [
     'Connection',
     'ConnectionManager',
+    'QueryRunner',
     'Repository',
     'add',
     'connect',
@@ -39,18 +41,3 @@ async def disconnect() -> None:
     connection manager.
     """
     return await connections.disconnect()
-
-
-def get(name: str) -> Connection:
-    """Return the named connection `name`."""
-    return connections.get(name)
-
-
-def session(name: str) -> AsyncSession:
-    """Create a new :class:`sqlalchemy.ext.asyncio.AsyncSession`
-    instance for the named connection `name`.
-    """
-    connection = get(name)
-    if not connection.is_connected():
-        raise RuntimeError(f"Connection '{name}' is not established.")
-    return connection.get_session()
